@@ -23,6 +23,7 @@ from barbican.common import validators
 from barbican import i18n as u
 from barbican.model import models
 from barbican.model import repositories as repo
+from barbican.plugin import util as putil
 
 LOG = utils.getLogger(__name__)
 
@@ -353,6 +354,8 @@ class SecretConsumersController(controllers.ACLMixin):
 
         consumer = self.consumer_repo.get_by_values(
             self.secret_id,
+            data["service"],
+            data["resource_type"],
             data["resource_id"],
             suppress_exception=True
         )
@@ -374,7 +377,7 @@ class SecretConsumersController(controllers.ACLMixin):
             _consumer_not_found()
 
         ret_data = self._return_secret_data(self.secret_id)
-        LOG.info('Deleted a consumer for project: %s',
+        LOG.info('Deleted a secret consumer for project: %s',
                  external_project_id)
         return ret_data
 
@@ -388,8 +391,7 @@ class SecretConsumersController(controllers.ACLMixin):
     def _return_secret_data(self, secret_id):
         secret = self._get_secret(secret_id)
 
-        dict_fields = secret.to_dict_fields()
+        secret_fields = putil.mime_types.augment_fields_with_content_types(
+            secret)
 
-        return hrefs.convert_to_hrefs(
-            hrefs.convert_to_hrefs(dict_fields)
-        )
+        return hrefs.convert_to_hrefs(secret_fields)
