@@ -13,7 +13,7 @@
 #  under the License.
 
 import pecan
-from six.moves.urllib import parse
+from urllib import parse
 
 from barbican import api
 from barbican.api import controllers
