@@ -18,8 +18,6 @@ import base64
 import re
 
 import jsonschema as schema
-from ldap3.core import exceptions as ldap_exceptions
-from ldap3.utils.dn import parse_dn
 from oslo_utils import timeutils
 
 from barbican.api import controllers
@@ -417,22 +415,9 @@ class NewSecretMetadatumValidator(ValidatorBase):
             raise exception.InvalidMetadataKey()
 
 
-class CACommonHelpersMixin(object):
-    def _validate_subject_dn_data(self, subject_dn):
-        """Confirm that the subject_dn contains valid data
-
-        Validate that the subject_dn string parses without error
-        If not, raise InvalidSubjectDN
-        """
-        try:
-            parse_dn(subject_dn)
-        except ldap_exceptions.LDAPInvalidDnError:
-            raise exception.InvalidSubjectDN(subject_dn=subject_dn)
-
-
 # TODO(atiwari) - Split this validator module and unit tests
 # into smaller modules
-class TypeOrderValidator(ValidatorBase, CACommonHelpersMixin):
+class TypeOrderValidator(ValidatorBase):
     """Validate a new typed order."""
 
     def __init__(self):
@@ -855,34 +840,6 @@ class ProjectQuotaValidator(ValidatorBase):
         return json_data
 
 
-class NewCAValidator(ValidatorBase, CACommonHelpersMixin):
-    """Validate new CA(s)."""
-
-    def __init__(self):
-        self.name = 'CA'
-
-        self.schema = {
-            'type': 'object',
-            'properties': {
-                'name': {'type': 'string', "minLength": 1},
-                'subject_dn': {'type': 'string', "minLength": 1},
-                'parent_ca_ref': {'type': 'string', "minLength": 1},
-                'description': {'type': 'string'},
-            },
-            'required': ['name', 'subject_dn', 'parent_ca_ref'],
-            'additionalProperties': False
-        }
-
-    def validate(self, json_data, parent_schema=None):
-        schema_name = self._full_name(parent_schema)
-
-        self._assert_schema_is_valid(json_data, schema_name)
-
-        subject_dn = json_data['subject_dn']
-        self._validate_subject_dn_data(subject_dn)
-        return json_data
-
-
 class SecretConsumerValidator(ValidatorBase):
     """Validate a new Secret Consumer."""
 
