@@ -383,7 +383,7 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
         self.transport_key_id = 'tkey12345'
 
     @mock.patch('barbican.plugin.resources.get_transport_key_id_for_retrieval')
-    def test_should_get_secret_as_json(self, mock_get_transport_key):
+    def _test_should_get_secret_as_json(self, mock_get_transport_key):
         mock_get_transport_key.return_value = None
         resp = self.app.get(
             '/secrets/{0}/'.format(self.secret.id),
@@ -400,6 +400,17 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
                       resp.namespace['content_types'].values())
         self.assertNotIn('mime_type', resp.namespace)
 
+        return resp.json
+
+    def test_should_get_secret_as_json_v0(self):
+        secret = self._test_should_get_secret_as_json()
+        self.assertNotIn('consumers', secret)
+
+    def test_should_get_secret_as_json_v1(self):
+        utils.set_version(self.app, '1.1')
+        secret = self._test_should_get_secret_as_json()
+        self.assertIn('consumers', secret)
+
     @testcase.attr('deprecated')
     @mock.patch('barbican.plugin.resources.get_secret')
     def test_should_get_secret_as_plain_based_on_content_type(self,
@@ -1251,6 +1262,7 @@ class WhenCreatingSecretConsumersUsingResource(FunctionalTest):
         return RootController()
 
     def _init(self):
+        self.name = 'test container name'
         self.external_project_id = 'keystoneid1234'
         self.project_internal_id = 'projectid1234'
 
@@ -1260,8 +1272,35 @@ class WhenCreatingSecretConsumersUsingResource(FunctionalTest):
         self.project.external_id = self.external_project_id
 
         # Set up mocked secret
-        self.secret = models.Secret()
-        self.secret.id = utils.generate_test_valid_uuid()
+        secret_id = utils.generate_test_valid_uuid()
+        datum_id = "iddatum1"
+        kek_id = "idkek1"
+
+        self.secret_algorithm = "AES"
+        self.secret_bit_length = 256
+        self.secret_mode = "CBC"
+
+        self.kek_project = models.KEKDatum()
+        self.kek_project.id = kek_id
+        self.kek_project.active = True
+        self.kek_project.bind_completed = False
+        self.kek_project.kek_label = "kek_label"
+
+        self.datum = models.EncryptedDatum()
+        self.datum.id = datum_id
+        self.datum.secret_id = secret_id
+        self.datum.kek_id = kek_id
+        self.datum.kek_meta_project = self.kek_project
+        self.datum.content_type = "text/plain"
+        self.datum.cypher_text = "aaaa"  # base64 value.
+
+        self.secret = create_secret(id_ref=secret_id,
+                                    name=self.name,
+                                    algorithm=self.secret_algorithm,
+                                    bit_length=self.secret_bit_length,
+                                    mode=self.secret_mode,
+                                    encrypted_datum=self.datum,
+                                    content_type=self.datum.content_type)
         self.secret.project = self.project
         self.secret.project_id = self.project_internal_id
 
@@ -1309,6 +1348,7 @@ class WhenCreatingSecretConsumersUsingResource(FunctionalTest):
         args, kwargs = self.consumer_repo.create_or_update_from.call_args
         consumer = args[0]
         self.assertIsInstance(consumer, models.SecretConsumerMetadatum)
+        self.assertIn('content_types', resp.namespace)
 
     def test_should_fail_consumer_bad_json(self):
         resp = self.app.post(
@@ -1346,6 +1386,7 @@ class WhenGettingOrDeletingSecretConsumersUsingResource(FunctionalTest):
         return RootController()
 
     def _init(self):
+        self.name = 'test container name'
         self.external_project_id = 'keystoneid1234'
         self.project_internal_id = 'projectid1234'
 
@@ -1355,8 +1396,35 @@ class WhenGettingOrDeletingSecretConsumersUsingResource(FunctionalTest):
         self.project.external_id = self.external_project_id
 
         # Set up mocked secret
-        self.secret = models.Secret()
-        self.secret.id = utils.generate_test_valid_uuid()
+        secret_id = utils.generate_test_valid_uuid()
+        datum_id = "iddatum1"
+        kek_id = "idkek1"
+
+        self.secret_algorithm = "AES"
+        self.secret_bit_length = 256
+        self.secret_mode = "CBC"
+
+        self.kek_project = models.KEKDatum()
+        self.kek_project.id = kek_id
+        self.kek_project.active = True
+        self.kek_project.bind_completed = False
+        self.kek_project.kek_label = "kek_label"
+
+        self.datum = models.EncryptedDatum()
+        self.datum.id = datum_id
+        self.datum.secret_id = secret_id
+        self.datum.kek_id = kek_id
+        self.datum.kek_meta_project = self.kek_project
+        self.datum.content_type = "text/plain"
+        self.datum.cypher_text = "aaaa"  # base64 value.
+
+        self.secret = create_secret(id_ref=secret_id,
+                                    name=self.name,
+                                    algorithm=self.secret_algorithm,
+                                    bit_length=self.secret_bit_length,
+                                    mode=self.secret_mode,
+                                    encrypted_datum=self.datum,
+                                    content_type=self.datum.content_type)
         self.secret.project = self.project
         self.secret.project_id = self.project_internal_id
 
@@ -1453,12 +1521,13 @@ class WhenGettingOrDeletingSecretConsumersUsingResource(FunctionalTest):
         self.assertEqual(200, resp.status_int)
 
     def test_should_delete_consumer(self):
-        self.app.delete_json('/secrets/{0}/consumers/'.format(
+        resp = self.app.delete_json('/secrets/{0}/consumers/'.format(
             self.secret.id
         ), self.consumer_ref)
 
         self.consumer_repo.delete_entity_by_id.assert_called_once_with(
             self.consumer.id, self.external_project_id)
+        self.assertIn('content_types', resp.namespace)
 
     def test_should_fail_deleting_consumer_bad_json(self):
         resp = self.app.delete(
