@@ -9,8 +9,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import six
-
 from barbican.common import exception
 from barbican.model import models
 from barbican.model import repositories
@@ -89,7 +87,7 @@ class WhenTestingContainerConsumerRepository(utils.RepositoryTestCase):
             session=session)
         self.assertIn(
             "SQL constraint check failed",
-            six.text_type(exception_result))
+            str(exception_result))
 
     def test_should_raise_no_result_found_get_container_id(self):
         session = self.repo.get_session()
